﻿--[[---------------------------------------------------------------------------

Copyright (c) 2008 by K. Scott Piel 
All Rights Reserved

E-mail: < kscottpiel@gmail.com >
Web:    < http://www.scottpiel.com >

This file is part of nUI.

    nUI is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    nUI is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with nUI.  If not, see <http://www.gnu.org/licenses/>.
	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--]]---------------------------------------------------------------------------
	
-- party panel

function nUI:createPartyInfo()
	
	if not nUI.party_frame then
		nUI.party_frame = CreateFrame( "Frame", "nUI_PartyFrame", nUI.info_frame, "SecureFrameTemplate" );
		
		nUI.info_frame:SetAttribute( "addchild", nUI.party_frame );
		nUI.party_frame:SetAttribute( "showstates", 2 );
		
		nUI:addInfoMode( "Party", 2 );
	
	end
	
	nUI.party_frame:SetWidth( nUI.info_frame:GetWidth() * 3 );
	nUI.party_frame:SetHeight( nUI.info_frame:GetHeight() * 3 );
	nUI.party_frame:SetScale( 1 / 3 );
	nUI.party_frame:SetPoint( "CENTER", nUI.info_frame, "CENTER", 0, 0 );
	nUI.party_frame.unit = {};

	local unit_height = nUI.party_frame:GetHeight() / 4;
	local unit_width  = nUI.party_frame:GetWidth();
	
	-- party 1 - 4
	
	local pet_targets = nUI_Config.party_ptargets;
	local layouts = {};
	
	if nUI_Config.party_pets == "no" then
		pet_targets = "no";
	end
	
	for i=1,4 do

		-- the party member
		
		id = "party"..i;
		
		layouts[id]                           = {};
		layouts[id].Portrait                  = {};
		layouts[id].StatusBars                = {};
		layouts[id].CastingBars               = {};
		layouts[id].Size                      = {};
		layouts[id].Origin                    = {};
		layouts[id].BuffInfo                  = {};
		layouts[id].BuffInfo                  = {};
		layouts[id].BuffInfo.Buffs            = {};
		layouts[id].BuffInfo.Debuffs          = {};
		layouts[id].BuffInfo.Buffs.rows       = 14;
		layouts[id].BuffInfo.Buffs.location   = "right";
		layouts[id].BuffInfo.Debuffs.rows     = 14;
		layouts[id].BuffInfo.Debuffs.location = "left";
		layouts[id].id                        = i;
		layouts[id].name                      = "nUI_PartyUnit"..i;
		layouts[id].orientation               = "left";
		layouts[id].show_reaction             = "no";
		layouts[id].Portrait.visible          = (nUI_Config.unit_anim == "no" and "yes" or "anim");
		layouts[id].StatusBars.visible        = "yes";
		layouts[id].StatusBars.values         = "none";
		layouts[id].StatusBars.total          = "none";
		layouts[id].CastingBars.visible       = "yes";
		layouts[id].Size.two_line             = "yes";
		layouts[id].Size.width                = unit_width * 0.45;
		layouts[id].Size.height               = unit_height * 0.75;
		layouts[id]                           = nUI.Class.UnitLayout:new( id, layouts[id] );

		-- the party member's target
		
		local tid = id.."target";
		
		layouts[tid]                    = {};
		layouts[tid].Portrait           = {};
		layouts[tid].StatusBars         = {};
		layouts[tid].Size               = {};
		layouts[tid].Origin             = {};
		layouts[tid].name               = "nUI_PartyUnit"..i;
		layouts[tid].orientation        = "left";
		layouts[tid].show_detail        = "no";
		layouts[tid].show_reaction      = "yes";
		layouts[tid].Portrait.visible   = "no";
		layouts[tid].StatusBars.visible = "no";
		layouts[tid].Size.width         = layouts[id].Size.width * 0.61;
		layouts[tid].Size.height        = unit_height - layouts[id].Size.height + 10;
		layouts[tid]                    = nUI.Class.UnitLayout:new( tid, layouts[tid] );

		-- the party member's pet
		
		local pid = "partypet"..i;
		
		layouts[pid]                    = {};
		layouts[pid].Portrait           = {};
		layouts[pid].StatusBars         = {};
		layouts[pid].Size               = {};
		layouts[pid].Origin             = {};
		layouts[pid].id                 = i;
		layouts[pid].name               = "nUI_PartyUnit"..i;
		layouts[pid].orientation        = "right";
		layouts[pid].is_visible         = nUI_Config.party_pets;
		layouts[pid].show_detail        = "yes";
		layouts[pid].show_reaction      = "no";
		layouts[pid].show_class         = "no";
		layouts[pid].Portrait.visible   = (nUI_Config.unit_anim == "no" and "yes" or "anim");
		layouts[pid].StatusBars.visible = "yes";
		layouts[pid].StatusBars.percent = "none";
		layouts[pid].StatusBars.values  = "none";
		layouts[pid].StatusBars.total   = "none";
		layouts[pid].Size.width         = unit_width * 0.25;
		layouts[pid].Size.height        = layouts[id].Size.height;
		layouts[pid].Size.two_line      = "yes";
		layouts[pid]                    = nUI.Class.UnitLayout:new( pid, layouts[pid] );
			
		-- the party member's pet's target
		
		local ptid = pid.."target";
		
		layouts[ptid]                    = {};
		layouts[ptid].Portrait           = {};
		layouts[ptid].StatusBars         = {};
		layouts[ptid].Size               = {};
		layouts[ptid].Origin             = {};
		layouts[ptid].name               = "nUI_PartyUnit"..i;
		layouts[ptid].orientation        = "right";
		layouts[ptid].show_detail        = "no";
		layouts[ptid].is_visible         = pet_targets;
		layouts[ptid].Portrait.visible   = "no";
		layouts[ptid].StatusBars.visible = "no";
		layouts[ptid].Size.width         = layouts[pid].Size.width;
		layouts[ptid].Size.height        = layouts[tid].Size.height;
		layouts[ptid]                    = nUI.Class.UnitLayout:new( ptid, layouts[ptid] );
		
		-- create the units

		local unit = {};
		local res_id = (i - 1) * 4;
		
		unit[id]   = nUI.Class.Unit:new( nUI.party_frame, res_id,   layouts[id] );
		unit[tid]  = nUI.Class.Unit:new( nUI.party_frame, res_id+1, layouts[tid] );
		unit[pid]  = nUI.Class.Unit:new( nUI.party_frame, res_id+2, layouts[pid] );
		unit[ptid] = nUI.Class.Unit:new( nUI.party_frame, res_id+3, layouts[ptid] );
		
		nUI.Units[id]   = unit[id];
		nUI.Units[tid]  = unit[tid];
		nUI.Units[pid]  = unit[pid];
		nUI.Units[ptid] = unit[ptid];
		
		nUI.party_frame.unit[i] = unit;
		
		local yOfs = ((i-1) * unit_height - 2) * nUI.scale;
		
		unit[id]:SetPoint( "TOPLEFT", nUI.party_frame, "TOPLEFT", unit_width * 0.08 * nUI.scale, -yOfs );
		unit[tid]:SetPoint( "TOPRIGHT", unit[id].event_frame, "BOTTOMRIGHT", 0, 6 * nUI.scale );

		unit[pid]:SetPoint( "TOPRIGHT", nUI.party_frame, "TOPRIGHT", 1, -yOfs );
		unit[ptid]:SetPoint( "TOPLEFT", unit[pid].event_frame, "BOTTOMLEFT", 0, 6 * nUI.scale );
		
	end		
end
